ParquetGraphDB
========================

- :class:`ParquetGraphDB <parquetdb.graph.parquet_graphdb.ParquetGraphDB>` - A manager for a graph storing multiple node types and edge types. Each node type and edge type is backed by a separate ParquetDB instance (wrapped by NodeStore or EdgeStore).

.. autosummary::
   :toctree: _autosummary

   parquetdb.graph.parquet_graphdb.ParquetGraphDB
